import axios from 'axios';

// Default global configuration
const globalConfig = {
  baseURL: '',
  // Default base URL
  headers: {},
  // Default headers
  defaultOptions: {
    retry: 0,
    // Retry attempts for failed requests
    refetchOnMount: false,
    // React Query refetch behavior
    refetchOnWindowFocus: false,
    // React Query refetch behavior
    networkMode: 'always' // React Query network mode
  }
};

// Create a singleton Axios instance
export const axiosInstance = axios.create({
  baseURL: globalConfig.baseURL,
  headers: globalConfig.headers
});

/**
 * Updates the global configuration and Axios instance with user-provided settings.
 *
 * @param {Object} config - Configuration object with baseURL, headers, and other options.
 */
export const configureSWDQuery = config => {
  if (!config || typeof config !== 'object') {
    throw new Error('Invalid configuration. Please provide an object.');
  }

  // Update global configuration
  Object.assign(globalConfig, config);

  // Update Axios instance configurations
  if (config.baseURL) {
    axiosInstance.defaults.baseURL = config.baseURL;
  }
  if (config.headers) {
    axiosInstance.defaults.headers = {
      ...axiosInstance.defaults.headers,
      // Keep existing headers
      ...config.headers // Merge new headers
    };
  }
};

/**
 * Adds additional headers dynamically.
 *
 * @param {Object} headers - Additional headers to be added.
 */
export const addHeaders = headers => {
  if (!headers || typeof headers !== 'object') {
    throw new Error('Invalid headers. Please provide an object.');
  }

  // Update global configuration headers
  globalConfig.headers = {
    ...globalConfig.headers,
    ...headers
  };

  // Update Axios instance headers
  axiosInstance.defaults.headers = {
    ...axiosInstance.defaults.headers,
    ...headers
  };
};

/**
 * Retrieves the current global configuration.
 *
 * @returns {Object} - The global configuration object.
 */
export const getConfig = () => globalConfig;
export default axiosInstance;